# pyodcollect
> Python3 bindings and command line tool to access OdourCollect's Citizen Observatory data in real time.

This python module provides a basic, read only interface with [OdourCollect.eu](https://odourcollect.eu)'s odour observation data API, as well as a command line tool to download data from OdourCollect directly info a CSV or a XLSX file.
It also provides some data enrichment features not available in OdourCollect.eu webapp that are very useful for data analysis purposes.

Please, check out [USAGE.md](https://github.com/ScienceForChange/pyodcollect/blob/main/USAGE.md) to use the module and the CLI tool.
 
## About OdourCollect.eu
[OdourCollect.eu](https://odourcollect.eu) is one of the most acknowledged Citizen Observatories (CO's) in Citizen Science (CS) landscape.
OdourCollect's main goal is providing an open, free platform for the citizens to report odour observations, making a worldwide collaborative odour map.

Albeit it allows reporting nice odours as well as bad ones, it has become popular for its potential to provide hard evidence of bad odour episodes 
happening in neighborhoods that are affected by odour emiting facilities like waste water processing, livestock, oil etc.

OdourCollect was an idea of Rosa Arias, CEO and founder of [Science for Change](https://scienceforchange.eu),  inspired by a standardized European methodology to evaluate odour episodes through citizens' observations, `CEN 16841` which in turn is based on the German standard `VDI 3940:2006`. 
The last public version of OdourCollect's open source code can be obtained in [this repository](https://github.com/ScienceForChange/odourcollect.eu).    

OdourCollect has validated its bottom-up methodology in 10 pilot projects in 10 countries (Spain, Portugal, Greece, Bulgaria, Chile, Italy, UK, Germany, Austria and Uganda) and has been supported by Spanish and European grants since it was first launched in 2019:
  - The Research and Innovation program of the European Union Horizon 2020 under agreement No. 789315, in the context of the D-NOSES project.
  - FECYT, the Spanish Foundation for Science and Technology - Ministry of Science and Innovation. 
## About odour pollution
- Frequent exposure to annoying odours can cause headache, stress, anxiety, lack of concentration, insomnia or even increase respiratory problems. 
- Even though ambient odours are the second cause of environmental complaints after noise worldwide, lots of countries worldwide lack a legal regulatory framework to protect citizens' rights and health.
You can learn more about existing regulations in odour pollution in the [D-NOSES Policy brief](https://dnoses.eu/policy-brief).
- If your community is affected by odour pollution problems, you can [contact Science for Change](mailto://hello@scienceforchange.eu) for an evaluation of your case.